pub fn get_max_scale_for_border(
border_segments: &[BorderSegmentInfo],
) -> LayoutToDeviceScaleExpand description
Computes the maximum scale that we allow for this set of border parameters. capping the scale will result in rendering very large corners at a lower resolution and stretching them, so they will have the right shape, but blurrier.